#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_MNINE_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_MNINE_HPP_INCLUDED

#include <boost/simd/constant/include/constants/mnine.hpp>

#endif
